LiveVue.Components (LiveVue v1.2.1)

Copy Markdown View Source

Macros to improve the developer experience of crossing the Liveview/Vue boundary.

Summary

Functions

Generates functions local to your current module that can be used to render Vue components. TODO: This could perhaps be optimized to only read the files once per compilation.

Functions

__using__(opts)

(macro)

Generates functions local to your current module that can be used to render Vue components. TODO: This could perhaps be optimized to only read the files once per compilation.

These shortcut names are also registered so LiveVue.SharedPropsView can inject shared props and v-socket into <.ComponentName> tags during ~H compilation.

Examples

use LiveVue.Components, vue_root: ["./assets/vue", "./lib/my_app_web"]