LiveVue
(LiveVue v0.1.0)
Summary
Attributes
v-component (:string) (required) - Name of the Vue component.Examples include "YourComponent", and "directory/Example".class (:string) - Class to apply to the Vue component. Defaults to nil.v-ssr (:boolean) - Whether to render the component on the server. Defaults to nil.v-socket (:map) - LiveView socket, should be provided when rendering inside LiveView. Defaults to nil.- Global attributes are accepted.
Functions
Attributes
v-component (:string) (required) - Name of the Vue component.Examples include "YourComponent", and "directory/Example".class (:string) - Class to apply to the Vue component. Defaults to nil.v-ssr (:boolean) - Whether to render the component on the server. Defaults to nil.v-socket (:map) - LiveView socket, should be provided when rendering inside LiveView. Defaults to nil.- Global attributes are accepted.